@@ -46,6 +46,7 @@ app_driver_pws <- function() {
   )
 }
 
+longer_timeout <- 80000
 
 # JS code to click the resize button popup.
 # nolint start
@@ -110,9 +111,11 @@ testthat::test_that(
     app_driver <- shinytest2::AppDriver$new(
       app_driver_pws(),
       name = "pws",
-      variant = "app_driver_pws_ui"
+      variant = "app_driver_pws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
     # Check if there is an image.
     testthat::expect_true(is_visible("#plot_with_settings-plot_main > img", app_driver))
@@ -132,12 +135,14 @@ testthat::test_that(
     app_driver <- shinytest2::AppDriver$new(
       app_driver_pws(),
       name = "pws",
-      variant = "app_driver_pws_ui"
+      variant = "app_driver_pws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
     app_driver$run_js(click_download_popup)
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
     testthat::expect_equal(
       app_driver$get_text("#plot_with_settings-downbutton-file_format-label"),
@@ -194,9 +199,11 @@ testthat::test_that(
       name = "pws",
       variant = "app_driver_pws_ui",
       height = 1000,
-      width = 1000
+      width = 1000,
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
     app_driver$get_text(paste0(
       "#plot_with_settings-plot-with-settings > div > div > ",
       "div.teal-widgets.settings-buttons > bslib-tooltip.resize-button > div:nth-child(1)"
@@ -207,7 +214,7 @@ testthat::test_that(
     app_driver$set_inputs(`plot_with_settings-expbut` = TRUE)
 
     # Expand the plot and evaluate the output
-    app_driver$run_js(click_expand_popup, timeout = default_idle_timeout)
+    app_driver$run_js(click_expand_popup, timeout = longer_timeout)
     testthat::expect_true(is_visible("#bslib-full-screen-overlay", app_driver))
 
     # Resize button
@@ -232,12 +239,14 @@ testthat::test_that(
     app_driver <- shinytest2::AppDriver$new(
       app_driver_pws(),
       name = "pws",
-      variant = "app_driver_pws_ui"
+      variant = "app_driver_pws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
     app_driver$run_js(click_download_popup)
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
     testthat::expect_true(is_visible("#plot_with_settings-plot_main > img", app_driver))
 
     testthat::expect_equal(
@@ -272,16 +281,16 @@ testthat::test_that(
       name = "pws",
       variant = "app_driver_pws_ui",
       height = 1000,
-      width = 1000
+      width = 1000,
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
     testthat::expect_false(is_visible("#plot_with_settings-slider_ui", app_driver))
 
-    # nolint start
     app_driver$run_js(click_resize_popup)
-    # nolint end
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
 
     testthat::expect_identical(
@@ -315,10 +324,13 @@ testthat::test_that(
     app_driver <- shinytest2::AppDriver$new(
       app_driver_pws(),
       name = "pws",
-      variant = "app_driver_pws_ui"
+      variant = "app_driver_pws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
-
+    app_driver$wait_for_idle(timeout = longer_timeout)
+    app_driver$run_js(click_resize_popup)
+    app_driver$wait_for_idle(timeout = longer_timeout)
     app_driver$set_inputs(`plot_with_settings-height` = 1000)
     app_driver$set_inputs(`plot_with_settings-width_resize_switch` = 350)
 
@@ -337,12 +349,14 @@ testthat::test_that(
     app_driver <- shinytest2::AppDriver$new(
       app_driver_pws(),
       name = "pws",
-      variant = "app_driver_pws_ui"
+      variant = "app_driver_pws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
     app_driver$run_js(click_download_popup)
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout)
 
     filename <- app_driver$get_download("plot_with_settings-downbutton-data_download")
     testthat::expect_match(filename, "png$", fixed = FALSE)
@@ -358,12 +372,14 @@ testthat::test_that("e2e teal.widgets::plot_with_settings: expanded image can be
     name = "pws",
     variant = "app_driver_pws_ui",
     height = 1000,
-    width = 1000
+    width = 1000,
+    timeout = 30000,
+    load_timeout = 100000
   )
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   app_driver$run_js(click_expand_popup)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   plot_before <- get_active_module_pws_output(app_driver, pws = "plot_modal", attr = "src")
   values <- app_driver$get_values()
@@ -377,11 +393,11 @@ testthat::test_that("e2e teal.widgets::plot_with_settings: expanded image can be
     400L
   )
   app_driver$run_js(click_resize_popup)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   app_driver$set_inputs(`plot_with_settings-height` = 1000)
   app_driver$set_inputs(`plot_with_settings-width` = 350)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
   values_resized <- app_driver$get_values()
 
   testthat::expect_equal(
@@ -409,15 +425,17 @@ testthat::test_that("e2e teal.widgets::plot_with_settings: expanded image can be
   app_driver <- shinytest2::AppDriver$new(
     app_driver_pws(),
     name = "pws",
-    variant = "app_driver_pws_ui"
+    variant = "app_driver_pws_ui",
+    timeout = 30000,
+    load_timeout = 100000
   )
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   app_driver$run_js(click_expand_popup)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   app_driver$run_js(click_download_popup)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   filename <- app_driver$get_download("plot_with_settings-downbutton-data_download")
   testthat::expect_match(filename, "png$", fixed = FALSE)
@@ -430,12 +448,14 @@ testthat::test_that("e2e teal.widgets::plot_with_settings: main image can be res
   app_driver <- shinytest2::AppDriver$new(
     app_driver_pws(),
     name = "pws",
-    variant = "app_driver_pws_ui"
+    variant = "app_driver_pws_ui",
+    timeout = 30000,
+    load_timeout = 100000
   )
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   app_driver$run_js(click_resize_popup)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   plot_before <- get_active_module_pws_output(app_driver, pws = "plot_main", attr = "src")
 
@@ -474,14 +494,16 @@ testthat::test_that("e2e teal.widgets::plot_with_settings: scrollbar appears whe
   app_driver <- shinytest2::AppDriver$new(
     app_driver_pws(),
     name = "pws",
-    variant = "app_driver_pws_ui"
+    variant = "app_driver_pws_ui",
+    timeout = 30000,
+    load_timeout = 100000
   )
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   app_driver$run_js(click_expand_popup)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
   app_driver$run_js(click_resize_popup)
-  app_driver$wait_for_idle(timeout = default_idle_timeout)
+  app_driver$wait_for_idle(timeout = longer_timeout)
 
   app_driver$set_inputs(`plot_with_settings-height` = 10000)
   app_driver$set_inputs(`plot_with_settings-width` = 350)
