@@ -31,6 +31,7 @@ app_driver_tws <- function() {
 }
 
 longer_timeout <- 80000
+longer_duration <- 1000
 
 # nolint start
 # JS code to click the expand button popup.
@@ -73,11 +74,13 @@ testthat::test_that(
       app_driver_tws(),
       name = "tws",
       variant = "app_driver_tws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = longer_timeout)
+    app_driver$wait_for_idle(timeout = longer_timeout * 4)
 
     # Check if there is an table.
-    testthat::expect_true(is_visible("#table_with_settings-table_out_main .rtables-container", app_driver))
+    testthat::expect_true(is_visible("#table_with_settings-table_out_main > .rtables-container", app_driver))
 
     # Check if the settings buttons are visible.
     testthat::expect_true(is_visible(".teal-widgets.settings-buttons", app_driver))
@@ -95,6 +98,8 @@ testthat::test_that(
       app_driver_tws(),
       name = "tws",
       variant = "app_driver_tws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
     app_driver$wait_for_idle(timeout = longer_timeout)
 
@@ -159,6 +164,8 @@ testthat::test_that(
       app_driver_tws(),
       name = "tws",
       variant = "app_driver_tws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
     app_driver$wait_for_idle(timeout = longer_timeout)
 
@@ -186,14 +193,16 @@ testthat::test_that(
       app_driver_tws(),
       name = "tws",
       variant = "app_driver_tws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = longer_timeout)
+    app_driver$wait_for_idle(duration = longer_duration, timeout = longer_timeout * 4)
 
     testthat::expect_false(is_visible("#table_with_settings-table_out_main", app_driver))
     testthat::expect_false(is_visible("#bslib-full-screen-overlay", app_driver))
 
     app_driver$run_js(click_expand_popup)
-    app_driver$wait_for_idle(timeout = longer_timeout)
+    app_driver$wait_for_idle(duration = longer_duration, timeout = longer_timeout * 4)
 
     table_content <- app_driver$get_text("#table_with_settings-table_out_main")
 
@@ -202,7 +211,8 @@ testthat::test_that(
     testthat::expect_true(is_visible("#bslib-full-screen-overlay", app_driver))
     # Close modal.
     app_driver$run_js("document.querySelector('#bslib-full-screen-overlay .bslib-full-screen-exit').click();")
-    app_driver$wait_for_idle(timeout = longer_timeout)
+
+    app_driver$wait_for_idle(duration = longer_duration, timeout = longer_timeout * 4)
     testthat::expect_false(is_visible("#bslib-full-screen-overlay", app_driver))
 
     # Review the main table content.
@@ -222,6 +232,8 @@ testthat::test_that(
       app_driver_tws(),
       name = "tws",
       variant = "app_driver_tws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
     app_driver$wait_for_idle(timeout = longer_timeout)
 
@@ -288,6 +300,8 @@ testthat::test_that(
       app_driver_tws(),
       name = "tws",
       variant = "app_driver_tws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
     app_driver$wait_for_idle(timeout = longer_timeout)
 
@@ -312,17 +326,18 @@ testthat::test_that(
       app_driver_tws(),
       name = "tws",
       variant = "app_driver_tws_ui",
+      timeout = 30000,
+      load_timeout = 100000
     )
-    app_driver$wait_for_idle(timeout = longer_timeout)
+    app_driver$wait_for_idle(duration = longer_duration, timeout = longer_timeout * 4)
 
     app_driver$run_js(click_download_popup)
-    app_driver$wait_for_idle(timeout = longer_timeout)
+    app_driver$wait_for_idle(duration = longer_duration, timeout = longer_timeout * 4)
 
     filename <- app_driver$get_download("table_with_settings-downbutton-data_download")
     testthat::expect_match(filename, "txt$", fixed = FALSE)
 
     content <- readLines(filename)
-
     check_table(content)
 
     app_driver$stop()
@@ -335,6 +350,8 @@ testthat::test_that("e2e teal.widgets::table_with_settings: expanded table can b
     app_driver_tws(),
     name = "tws",
     variant = "app_driver_tws_ui",
+    timeout = 30000,
+    load_timeout = 100000
   )
   app_driver$wait_for_idle(timeout = longer_timeout)
 
